[Qa-jenkins-scm] [jenkins.debian.net] 02/02: chroot-installations: also test design-desktop* metapackages

Holger Levsen holger at layer-acht.org
Sat Apr 29 12:38:57 UTC 2017


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit 31fe62b728d6b5fb5765dfcc232b173db21698f3
Author: Holger Levsen <holger at layer-acht.org>
Date:   Sat Apr 29 14:38:44 2017 +0200

    chroot-installations: also test design-desktop* metapackages
    
    Signed-off-by: Holger Levsen <holger at layer-acht.org>
---
 bin/chroot-installation.sh          |  2 ++
 job-cfg/chroot-installation.yaml.py | 10 ++++++++--
 2 files changed, 10 insertions(+), 2 deletions(-)

diff --git a/bin/chroot-installation.sh b/bin/chroot-installation.sh
index fdb5c0c..5ffa5dd 100755
--- a/bin/chroot-installation.sh
+++ b/bin/chroot-installation.sh
@@ -272,6 +272,8 @@ if [ "$2" != "" ] ; then
 				;;
 		parl-desktop*)	install_packages "Debian Parl package" $2
 				;;
+		design-desktop*)	install_packages "Debian Design package" $2
+				;;
 		*)		echo "unsupported component."
 				exit 1
 				;;
diff --git a/job-cfg/chroot-installation.yaml.py b/job-cfg/chroot-installation.yaml.py
index 6eb39b0..7a61f49 100755
--- a/job-cfg/chroot-installation.yaml.py
+++ b/job-cfg/chroot-installation.yaml.py
@@ -90,6 +90,10 @@ all_targets = [
    'parl-desktop-eu',
    'parl-desktop-strict',
    'parl-desktop-world',
+   'design-desktop-animation',
+   'design-desktop-graphics',
+   'design-desktop-strict',
+   'design-desktop-web',
    ]
 
 #
@@ -108,8 +112,8 @@ def is_target_in_distro(distro, target):
          # education-thin-client-server is obsolete since stretch…
          elif distro in ('sid', 'buster') and target == 'education-thin-client-server':
              return False
-         # education-lang-* and parl-desktop* packages only exist since stretch
-         elif distro in ('wheezy', 'jessie') and (target[:15] == 'education-lang-' or target[:12] == 'parl-desktop'):
+         # education-lang-*, parl-desktop* and design-desktop* packages only exist since stretch
+         elif distro in ('wheezy', 'jessie') and (target[:15] == 'education-lang-' or target[:12] == 'parl-desktop' or target[:14] == 'design-desktop'):
              return False
          return True
 
@@ -167,6 +171,8 @@ spoken_names = {
 def get_spoken_name(target):
     if target[:12] == 'parl-desktop':
          return 'the Debian Parl metapackage '+target
+    elif target[:14] == 'design-desktop':
+         return 'the Debian Parl metapackage '+target
     elif target[:10] == 'education-':
          return 'the Debian Edu metapackage '+target
     elif target in spoken_names:

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list